package MainPackage;

import java.io.Serializable;
import java.util.Date;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import java.util.concurrent.TimeUnit;

public class Job implements Serializable {

	private long length = 0;
	private static long alljobid = 0;
	public final long thisjobid = alljobid++;
	private String name;
	private Date stoptime, starttime;
	private List<Job> nextjob = new LinkedList<Job>(),
			previousjob = new LinkedList<Job>();
	private Resource res;

	public Job(String name2, long length) {
		this.name = name2;
		this.length = length;
	}

	@Override
	public String toString() {
		return this.name;
	}

	public String getFullInfo() {
		return this.name + " \r\n starttime: " + this.starttime.toString()
				+ " \r\n stoptime: " + this.stoptime.toString();
	}

	public Date getStartTime() {
		return this.starttime;
	}

	public Date getStopTime() {
		return this.stoptime;
	}

	public Job(String name2, Date starttime, long length) {
		this(name2, length);
		this.starttime = starttime;
	}

	public Job(String name2, Date starttime, Date stoptime, long length) {
		this(name2, starttime, length);
		this.stoptime = stoptime;
	}

	public Job(String name2, Date starttime, Date stoptime, Job previousjob,
			long length) {
		this(name2, starttime, stoptime, length);
		this.setPreviousJob(previousjob);
	}

	public Job(String name2, Date starttime, Date stoptime, Job previousjob,
			Job nextjob, long length) {
		this(name2, starttime, stoptime, previousjob, length);
		this.setNextJob(nextjob);
	}

	public Job(String name2, Date starttime, Date stoptime, Job previousjob,
			Job nextjob, Resource worker, long length) {
		this(name2, starttime, stoptime, previousjob, nextjob, length);
		if (worker != null) {
			this.setResource(worker);

		}
	}

	public boolean hasWorker() {
		if (res != null && res instanceof Resource)
			return true;
		return false;
	}

	public boolean setPreviousJob(Job prevJob) {
		if (this == prevJob || this.nextjob.contains(prevJob)
				|| this.previousjob.contains(prevJob) || prevJob == null)
			return false;
		else
			this.previousjob.add(prevJob);
		if (prevJob != null)
			prevJob.setNextJob(this);
		return true;
	}

	public void removePreviousJob() {
		this.previousjob.clear();
		;
	}

	public boolean setNextJob(Job nexJob) {
		if (this == nexJob || this.nextjob.contains(nexJob)
				|| this.previousjob.contains(nexJob) || nexJob == null)
			return false;
		this.nextjob.add(nexJob);
		if (nexJob != null)
			nexJob.setPreviousJob(this);
		return true;

	}

	public void removeNextJob() {
		this.nextjob.clear();
	}

	public void setResource(Resource res) {
		this.res = res;
		this.res.addJob(this);
	}

	public void removeResource() {
		this.res.removeJob(this);
		this.res = null;
	}

	public boolean setStartTime(Date stt) {
		if (stt.after(stoptime))
			return false;
		else
			starttime = stt;
		return true;
	}

	public boolean setStopTime(Date stt) {
		if (stt.before(starttime))
			return false;
		else
			stoptime = stt;
		return true;
	}

	public String getName() {
		return this.name + ":" + thisjobid;
	}

	public List<Job> getNextJob() {
		return this.nextjob;
	}

	public List<Job> getPreviousJob() {
		return this.previousjob;
	}

	public Resource getResource() {
		// TODO Auto-generated method stub
		return this.res;
	}

	public void setName(String text) {
		this.name = text;
	}

	public long getLength() {
		// TODO Auto-generated method stub
		return this.length;
	}

	public void setLength(long length2) {
		this.length = length2;

	}
}
